@@ -134,6 +134,7 @@ BuildArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
+        "bucketOwnerAccess": Literal["NONE", "READ_ONLY", "FULL"],
     },
     total=False,
 )
@@ -448,6 +449,7 @@ _OptionalProjectArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
+        "bucketOwnerAccess": Literal["NONE", "READ_ONLY", "FULL"],
     },
     total=False,
 )
@@ -689,7 +691,13 @@ _RequiredS3LogsConfigTypeDef = TypedDict(
     "_RequiredS3LogsConfigTypeDef", {"status": Literal["ENABLED", "DISABLED"]}
 )
 _OptionalS3LogsConfigTypeDef = TypedDict(
-    "_OptionalS3LogsConfigTypeDef", {"location": str, "encryptionDisabled": bool}, total=False
+    "_OptionalS3LogsConfigTypeDef",
+    {
+        "location": str,
+        "encryptionDisabled": bool,
+        "bucketOwnerAccess": Literal["NONE", "READ_ONLY", "FULL"],
+    },
+    total=False,
 )
 
 
